==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/realm/entity/MapWebAuthnPolicyEntityDelegate.java <==
package org.keycloak.models.map.realm.entity;
public class MapWebAuthnPolicyEntityDelegate implements org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity> delegateProvider;
    public MapWebAuthnPolicyEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getRpEntityName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.RP_ENTITY_NAME).getRpEntityName();
    }
    @Override public void setRpEntityName(String rpEntityName) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.RP_ENTITY_NAME, rpEntityName).setRpEntityName(rpEntityName);
    }
    @Override public java.util.List<String> getSignatureAlgorithms() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.SIGNATURE_ALGORITHMS).getSignatureAlgorithms();
    }
    @Override public void setSignatureAlgorithms(java.util.List<String> signatureAlgorithms) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.SIGNATURE_ALGORITHMS, signatureAlgorithms).setSignatureAlgorithms(signatureAlgorithms);
    }
    @Override public String getRpId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.RP_ID).getRpId();
    }
    @Override public void setRpId(String rpId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.RP_ID, rpId).setRpId(rpId);
    }
    @Override public String getAttestationConveyancePreference() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.ATTESTATION_CONVEYANCE_PREFERENCE).getAttestationConveyancePreference();
    }
    @Override public void setAttestationConveyancePreference(String attestationConveyancePreference) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.ATTESTATION_CONVEYANCE_PREFERENCE, attestationConveyancePreference).setAttestationConveyancePreference(attestationConveyancePreference);
    }
    @Override public String getAuthenticatorAttachment() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.AUTHENTICATOR_ATTACHMENT).getAuthenticatorAttachment();
    }
    @Override public void setAuthenticatorAttachment(String authenticatorAttachment) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.AUTHENTICATOR_ATTACHMENT, authenticatorAttachment).setAuthenticatorAttachment(authenticatorAttachment);
    }
    @Override public String getRequireResidentKey() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.REQUIRE_RESIDENT_KEY).getRequireResidentKey();
    }
    @Override public void setRequireResidentKey(String requireResidentKey) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.REQUIRE_RESIDENT_KEY, requireResidentKey).setRequireResidentKey(requireResidentKey);
    }
    @Override public String getUserVerificationRequirement() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.USER_VERIFICATION_REQUIREMENT).getUserVerificationRequirement();
    }
    @Override public void setUserVerificationRequirement(String userVerificationRequirement) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.USER_VERIFICATION_REQUIREMENT, userVerificationRequirement).setUserVerificationRequirement(userVerificationRequirement);
    }
    @Override public Integer getCreateTimeout() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.CREATE_TIMEOUT).getCreateTimeout();
    }
    @Override public void setCreateTimeout(Integer createTimeout) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.CREATE_TIMEOUT, createTimeout).setCreateTimeout(createTimeout);
    }
    @Override public Boolean isAvoidSameAuthenticatorRegister() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.AVOID_SAME_AUTHENTICATOR_REGISTER).isAvoidSameAuthenticatorRegister();
    }
    @Override public void setAvoidSameAuthenticatorRegister(Boolean avoidSameAuthenticatorRegister) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.AVOID_SAME_AUTHENTICATOR_REGISTER, avoidSameAuthenticatorRegister).setAvoidSameAuthenticatorRegister(avoidSameAuthenticatorRegister);
    }
    @Override public java.util.List<String> getAcceptableAaguids() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.ACCEPTABLE_AAGUIDS).getAcceptableAaguids();
    }
    @Override public void setAcceptableAaguids(java.util.List<String> acceptableAaguids) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.ACCEPTABLE_AAGUIDS, acceptableAaguids).setAcceptableAaguids(acceptableAaguids);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapWebAuthnPolicyEntityDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapWebAuthnPolicyEntityDelegate implements org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity, org.keycloak.models.map.common.delegate.HasDelegateProvider<org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity> {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity> delegateProvider;
    public MapWebAuthnPolicyEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    public org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity> getDelegateProvider() {
        return this.delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getRpEntityName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.RP_ENTITY_NAME).getRpEntityName();
    }
    @Override public void setRpEntityName(String rpEntityName) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.RP_ENTITY_NAME, rpEntityName).setRpEntityName(rpEntityName);
    }
    @Override public java.util.List<String> getSignatureAlgorithms() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.SIGNATURE_ALGORITHMS).getSignatureAlgorithms();
    }
    @Override public void setSignatureAlgorithms(java.util.List<String> signatureAlgorithms) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.SIGNATURE_ALGORITHMS, signatureAlgorithms).setSignatureAlgorithms(signatureAlgorithms);
    }
    @Override public String getRpId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.RP_ID).getRpId();
    }
    @Override public void setRpId(String rpId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.RP_ID, rpId).setRpId(rpId);
    }
    @Override public String getAttestationConveyancePreference() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.ATTESTATION_CONVEYANCE_PREFERENCE).getAttestationConveyancePreference();
    }
    @Override public void setAttestationConveyancePreference(String attestationConveyancePreference) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.ATTESTATION_CONVEYANCE_PREFERENCE, attestationConveyancePreference).setAttestationConveyancePreference(attestationConveyancePreference);
    }
    @Override public String getAuthenticatorAttachment() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.AUTHENTICATOR_ATTACHMENT).getAuthenticatorAttachment();
    }
    @Override public void setAuthenticatorAttachment(String authenticatorAttachment) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.AUTHENTICATOR_ATTACHMENT, authenticatorAttachment).setAuthenticatorAttachment(authenticatorAttachment);
    }
    @Override public String getRequireResidentKey() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.REQUIRE_RESIDENT_KEY).getRequireResidentKey();
    }
    @Override public void setRequireResidentKey(String requireResidentKey) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.REQUIRE_RESIDENT_KEY, requireResidentKey).setRequireResidentKey(requireResidentKey);
    }
    @Override public String getUserVerificationRequirement() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.USER_VERIFICATION_REQUIREMENT).getUserVerificationRequirement();
    }
    @Override public void setUserVerificationRequirement(String userVerificationRequirement) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.USER_VERIFICATION_REQUIREMENT, userVerificationRequirement).setUserVerificationRequirement(userVerificationRequirement);
    }
    @Override public Integer getCreateTimeout() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.CREATE_TIMEOUT).getCreateTimeout();
    }
    @Override public void setCreateTimeout(Integer createTimeout) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.CREATE_TIMEOUT, createTimeout).setCreateTimeout(createTimeout);
    }
    @Override public Boolean isAvoidSameAuthenticatorRegister() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.AVOID_SAME_AUTHENTICATOR_REGISTER).isAvoidSameAuthenticatorRegister();
    }
    @Override public void setAvoidSameAuthenticatorRegister(Boolean avoidSameAuthenticatorRegister) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.AVOID_SAME_AUTHENTICATOR_REGISTER, avoidSameAuthenticatorRegister).setAvoidSameAuthenticatorRegister(avoidSameAuthenticatorRegister);
    }
    @Override public java.util.List<String> getAcceptableAaguids() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.ACCEPTABLE_AAGUIDS).getAcceptableAaguids();
    }
    @Override public void setAcceptableAaguids(java.util.List<String> acceptableAaguids) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.ACCEPTABLE_AAGUIDS, acceptableAaguids).setAcceptableAaguids(acceptableAaguids);
    }
}
